package Bencher::ScenarioR::CBlocks::Numeric;

our $VERSION = 0.003; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        dataset     => 316227,
        errors      => 0.00014,
        participant => "C::Blocks",
        rate        => 6.43,
        samples     => 6,
        time        => 155,
        vs_slowest  => 1,
      },
      {
        dataset     => 316227,
        errors      => 8.3e-05,
        participant => "perl",
        rate        => 6.95,
        samples     => 6,
        time        => 144,
        vs_slowest  => 1.08,
      },
      {
        dataset     => 100000,
        errors      => 3.3e-05,
        participant => "C::Blocks",
        rate        => 19.8,
        samples     => 6,
        time        => 50.6,
        vs_slowest  => 3.07,
      },
      {
        dataset     => 100000,
        errors      => 3.2e-05,
        participant => "perl",
        rate        => 22.1,
        samples     => 9,
        time        => 45.3,
        vs_slowest  => 3.43,
      },
      {
        dataset     => 31622,
        errors      => 2.9e-06,
        participant => "C::Blocks",
        rate        => 66.5,
        samples     => 6,
        time        => 15,
        vs_slowest  => 10.3,
      },
      {
        dataset     => 31622,
        errors      => 2e-06,
        participant => "perl",
        rate        => 70.4,
        samples     => 6,
        time        => 14.2,
        vs_slowest  => 10.9,
      },
      {
        dataset     => 10000,
        errors      => 3.9e-07,
        participant => "perl",
        rate        => 133,
        samples     => 6,
        time        => 7.516,
        vs_slowest  => 20.68,
      },
      {
        dataset     => 3235,
        errors      => 9.7e-08,
        participant => "perl",
        rate        => 683.8,
        samples     => 6,
        time        => 1.462,
        vs_slowest  => 106.3,
      },
      {
        dataset     => 1000,
        errors      => 5.3e-11,
        participant => "perl",
        rate        => 2212.87,
        samples     => 6,
        time        => 0.451902,
        vs_slowest  => 344,
      },
      {
        dataset     => 316,
        errors      => 6.4e-11,
        participant => "perl",
        rate        => 6993.43,
        samples     => 6,
        time        => 0.142991,
        vs_slowest  => 1087.16,
      },
      {
        dataset     => 10000,
        errors      => 0,
        participant => "C::Blocks",
        rate        => 8480.48,
        samples     => 6,
        time        => 0.117918,
        vs_slowest  => 1318.33,
      },
      {
        dataset     => 100,
        errors      => 0,
        participant => "C::Blocks",
        rate        => 20854.2,
        samples     => 6,
        time        => 0.0479519,
        vs_slowest  => 3241.88,
      },
      {
        dataset     => 100,
        errors      => 2.3e-08,
        participant => "perl",
        rate        => 21400,
        samples     => 7,
        time        => 0.0468,
        vs_slowest  => 3320,
      },
      {
        dataset     => 3235,
        errors      => 2.1e-11,
        participant => "C::Blocks",
        rate        => 32577.3,
        samples     => 6,
        time        => 0.0306962,
        vs_slowest  => 5064.28,
      },
      {
        dataset     => 31,
        errors      => 0,
        participant => "C::Blocks",
        rate        => 65280.9,
        samples     => 6,
        time        => 0.0153184,
        vs_slowest  => 10148.2,
      },
      {
        dataset     => 31,
        errors      => 0,
        participant => "perl",
        rate        => 69735.4,
        samples     => 6,
        time        => 0.0143399,
        vs_slowest  => 10840.7,
      },
      {
        dataset     => 1000,
        errors      => 0,
        participant => "C::Blocks",
        rate        => 103887,
        samples     => 6,
        time        => 0.0096258,
        vs_slowest  => 16149.7,
      },
      {
        dataset     => 10,
        errors      => 2.1e-11,
        participant => "C::Blocks",
        rate        => 202450,
        samples     => 6,
        time        => 0.0049396,
        vs_slowest  => 31471,
      },
      {
        dataset     => 10,
        errors      => 1.1e-08,
        participant => "perl",
        rate        => 210000,
        samples     => 7,
        time        => 0.0047,
        vs_slowest  => 33000,
      },
      {
        dataset     => 316,
        errors      => 3e-09,
        participant => "C::Blocks",
        rate        => 323000,
        samples     => 6,
        time        => 0.00309,
        vs_slowest  => 50300,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "CBlocks::Numeric",
                                          },
      "func.bencher_version"           => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2860.757,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => "2770.250",
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2889.906,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2600.226,
                                              stepping                     => 4,
                                            },
                                          ],
      "func.elapsed_time"              => 3.88052892684937,
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__" => 1.039,
                                            "Bencher::Scenario::CBlocks::Numeric" => undef,
                                            "Benchmark::Dumb" => "0.10",
                                            "C::Blocks" => 0.41,
                                            "Devel::Platform::Info" => 0.16,
                                            "perl" => "v5.24.0",
                                            "Sys::Info" => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0, 1], "dataset", [0 .. 9]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "rosa",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.19.0-32-generic",
                                            kname    => "Linux",
                                            kvers    => "3.19.0-32-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 17.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.19.0-32-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 6,
      "func.scenario_module"           => "Bencher::Scenario::CBlocks::Numeric",
      "func.scenario_module_md5sum"    => "7c0b7dd1416e9459ac84f8295586f76b",
      "func.scenario_module_mtime"     => 1485326981,
      "func.scenario_module_sha1sum"   => "34555f7b653c41978919236bc75dc8cb1e966f99",
      "func.scenario_module_sha256sum" => "8c295fdf37fb107618dd35936ef1a25ae2d854daecd797868ce1f7be61e2052b",
      "func.time_end"                  => 1499087546.31095,
      "func.time_factor"               => 1000,
      "func.time_start"                => 1499087542.43042,
      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, undef, "/s", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "dataset",
                                            "rate",
                                            "time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Benchmark numeric performance of C::Blocks

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

